@@ -13,6 +13,8 @@ import grpc
 from appzoo.grpc_app.base_pb2 import Request, Response
 from appzoo.grpc_app.base_pb2_grpc import GrpcServiceServicer, GrpcServiceStub, add_GrpcServiceServicer_to_server
 
+from pickle import dumps, loads
+
 
 class Client:
 
@@ -21,11 +23,14 @@ class Client:
         self._client = GrpcServiceStub(channel=self.conn)
 
     def request(self, data):
-        request = Request(data=data)
+        input = dumps(data)
+        request = Request(data=input)
         response = self._client._request(request)
-        return response.data
+
+        return loads(response.data)
 
 
 if __name__ == '__main__':
     client = Client()
-    print(client.request(['1, 2, 3, 4', 'as']))
+    _ = client.request(['1, 2, 3, 4', 'as'])
+    print(_)
