@@ -14,6 +14,7 @@ from appzoo.grpc_app.base_pb2 import Request, Response
 from appzoo.grpc_app.base_pb2_grpc import GrpcServiceServicer, GrpcServiceStub, add_GrpcServiceServicer_to_server
 
 from meutils.pipe import *
+from pickle import dumps, loads
 
 
 class Service(GrpcServiceServicer):
@@ -26,9 +27,12 @@ class Service(GrpcServiceServicer):
 
     @logger.catch()
     def _request(self, request, context):
+        input = loads(request.data)
         if self.debug:
-            logger.debug(request.data)
-        return Response(data=self.main(request.data))
+            logger.debug(input)
+
+        output = dumps(self.main(input))
+        return Response(data=output)
 
     def run(self, port=8000, max_workers=3):
 
@@ -48,7 +52,7 @@ class Service(GrpcServiceServicer):
 if __name__ == '__main__':
     class MyService(Service):
 
-        def main(self, data: list) -> list:
+        def main(self, data):
             return data
 
 
