@@ -32,5 +32,12 @@ app_ = app.app
 #
 # app.add_route_plus(proxy_app_, methods=["GET", "POST"], data=None)
 
+import time
+
+def f(kwargs):
+    return {'a': None, 'b': None, 'c': None, 't': pd.to_datetime('2022-08-03 10:06:45')}
+
+app.add_route_plus(f, methods=["GET", "POST"], data=None)
+
 if __name__ == '__main__':
     app.run(app.app_from(__file__), port=9955, debug=True)
